<?php

// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.

declare(strict_types=1);

namespace AxiosAssystModule\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * AxiosObjects Model
 *
 * @method \AxiosAssystModule\Model\Entity\AxiosObject get($primaryKey, $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject newEntity($data = null, array $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject[] newEntities(array $data, array $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject[] patchEntities($entities, array $data, array $options = [])
 * @method \AxiosAssystModule\Model\Entity\AxiosObject findOrCreate($search, callable $callback = null, $options = [])
 */
class AxiosObjectsTable extends Table {
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void {
        parent::initialize($config);

        $this->setTable('axios_objects');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator {
        $validator
            ->integer('id')
            ->allowEmptyString('id', null, 'create');

        $validator
            ->scalar('type')
            ->maxLength('type', 255)
            ->requirePresence('type', 'create')
            ->notEmptyString('type');

        $validator
            ->scalar('axios_id')
            ->integer('axios_id')
            ->requirePresence('axios_id', 'create')
            ->notEmptyString('axios_id');

        $validator
            ->scalar('element_id')
            ->integer('element_id')
            ->requirePresence('element_id', 'create')
            ->notEmptyString('element_id');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker {
        return $rules;
    }
}
